TickkiChatStrings constructor

const TickkiChatStrings({
  1. String title = 'Chat with us',
  2. String onlineLabel = 'Online',
  3. String offlineLabel = "We'll get back to you",
  4. String inputPlaceholder = 'Type a message…',
  5. String sendButton = 'Send',
  6. String attachButton = 'Attach file',
  7. String preChatTitle = 'Before we start',
  8. String preChatSubtitle = 'Tell us a bit about you so we can help.',
  9. String preChatNameLabel = 'Name',
  10. String preChatEmailLabel = 'Email',
  11. String preChatSubmit = 'Start chat',
  12. String errorGeneric = 'Something went wrong. Please try again.',
  13. String errorRateLimited = 'Too many messages too fast — slow down a bit and retry.',
  14. String errorNoConnection = "Can't reach the chat server. Check your connection.",
  15. String emptyHistory = 'Start the conversation. An agent will reply soon.',
  16. String typingIndicator = 'Agent is typing…',
})

Implementation

const TickkiChatStrings({
  this.title = 'Chat with us',
  this.onlineLabel = 'Online',
  this.offlineLabel = "We'll get back to you",
  this.inputPlaceholder = 'Type a message…',
  this.sendButton = 'Send',
  this.attachButton = 'Attach file',
  this.preChatTitle = 'Before we start',
  this.preChatSubtitle = 'Tell us a bit about you so we can help.',
  this.preChatNameLabel = 'Name',
  this.preChatEmailLabel = 'Email',
  this.preChatSubmit = 'Start chat',
  this.errorGeneric = 'Something went wrong. Please try again.',
  this.errorRateLimited =
      'Too many messages too fast — slow down a bit and retry.',
  this.errorNoConnection =
      "Can't reach the chat server. Check your connection.",
  this.emptyHistory = 'Start the conversation. An agent will reply soon.',
  this.typingIndicator = 'Agent is typing…',
});